@@ -2,8 +2,17 @@
 Generates a dictionary of ANSI escape codes
 
 http://en.wikipedia.org/wiki/ANSI_escape_code
+
+Uses colorama as an optional dependancy to support color on Windows
 """
 
+try:
+    import colorama
+except ImportError:
+    pass
+else:
+    colorama.init()
+
 __all__ = ['escape_codes']
 
 # Returns escape codes from format codes
